Introduction
============

The purpose of the optional ``allauth.usersessions`` app is to keep track of
(authenticated) user sessions, allowing users to view a list of all their active
sessions, as well as offering a means to end these sessions.
